"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const browserslist = require("browserslist");
const logger = require("../utils/logging");
const debug_1 = require("../utils/debug");
const debug = debug_1.debug(__filename);
exports.generateBrowserslistConfig = () => {
    debug('Initiating browserslist config generator');
    const addBrowsersListOptions = [
        { name: 'Default (last 2 versions of each browser, and browsers with globaly usage over 1%, plus Firefox ESR)', value: 'default' },
        { name: 'Custom (use browserslist format:  https://github.com/ai/browserslist#queries)', value: 'custom' }
    ];
    const browsersListQuestions = [
        {
            choices: addBrowsersListOptions,
            message: 'What browsers are you targeting?',
            name: 'targetBy',
            type: 'list'
        },
        {
            message: 'Please enter the queries you want to specify (Use comma as the separator if you have more than one query):',
            name: 'customQueries',
            when: (answers) => {
                return answers.targetBy === 'custom';
            }
        }
    ];
    const askAndValidate = async () => {
        const results = await inquirer.prompt(browsersListQuestions);
        if (results.targetBy === 'default') {
            return [];
        }
        const customQueries = results.customQueries.split(',').map((query) => {
            return query.trim();
        });
        try {
            browserslist(customQueries);
            return customQueries;
        }
        catch (err) {
            logger.log(`${err.message}.`);
            logger.log('Please try again.');
            return askAndValidate();
        }
    };
    return askAndValidate();
};
