"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DEFAULT_RULE_LEVEL = 'error';
const shortHandRulePrefixes = {
    '-': 'off',
    '?': 'warning'
};
const normalizeRule = (rule) => {
    let ruleLevel;
    let ruleName;
    for (const prefix in shortHandRulePrefixes) {
        if (rule.startsWith(prefix)) {
            ruleLevel = shortHandRulePrefixes[prefix];
            ruleName = rule.substr(1, rule.length - 1);
            break;
        }
    }
    if (!ruleLevel) {
        [ruleName, ruleLevel] = rule.split(':');
        ruleLevel = ruleLevel || DEFAULT_RULE_LEVEL;
    }
    return {
        ruleLevel,
        ruleName
    };
};
function normalizeRules(rules) {
    if (!Array.isArray(rules)) {
        return rules;
    }
    const result = {};
    for (const rule of rules) {
        if (typeof rule === 'string') {
            const { ruleName, ruleLevel } = normalizeRule(rule);
            result[ruleName] = ruleLevel;
        }
        else if (Array.isArray(rule)) {
            const [ruleKey, ruleConfig] = rule;
            const { ruleName, ruleLevel } = normalizeRule(ruleKey);
            result[ruleName] = [ruleLevel];
            if (ruleConfig) {
                result[ruleName].push(ruleConfig);
            }
        }
        else {
            throw new Error(`Invalid rule type specified: "${rule}". Arrays and objects are supported.`);
        }
    }
    return result;
}
exports.default = normalizeRules;
