"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const location_helpers_1 = require("./utils/location-helpers");
class RuleContext {
    constructor(ruleId, sonarwhal, severity, options, meta) {
        this.id = ruleId;
        this.options = options;
        this.meta = meta;
        this.sonarwhal = sonarwhal;
        this.severity = severity;
        Object.freeze(this);
    }
    get pageDOM() {
        return this.sonarwhal.pageDOM;
    }
    get pageContent() {
        return this.sonarwhal.pageContent;
    }
    get pageHeaders() {
        return this.sonarwhal.pageHeaders;
    }
    get targetedBrowsers() {
        return this.sonarwhal.targetedBrowsers;
    }
    get ruleOptions() {
        if (Array.isArray(this.options)) {
            return this.options[1];
        }
        return null;
    }
    evaluate(source) {
        return this.sonarwhal.evaluate(source);
    }
    fetchContent(target, headers) {
        return this.sonarwhal.fetchContent(target, headers);
    }
    querySelectorAll(selector) {
        return this.sonarwhal.querySelectorAll(selector);
    }
    findInElement(element, content) {
        return location_helpers_1.findInElement(element, content);
    }
    findProblemLocation(element, content) {
        return location_helpers_1.findProblemLocation(element, { column: 0, line: 0 }, content);
    }
    async report(resource, element, message, content, location, severity, codeSnippet) {
        let position = location;
        let sourceCode = null;
        if (element) {
            position = await location_helpers_1.findProblemLocation(element, { column: 0, line: 0 }, content);
            sourceCode = (await element.outerHTML()).replace(/[\t]/g, '    ');
        }
        this.sonarwhal.report(this.id, severity || this.severity, codeSnippet || sourceCode, position, message, resource);
    }
    on(event, listener) {
        this.sonarwhal.onRuleEvent(this.id, event, listener);
    }
}
exports.RuleContext = RuleContext;
