"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const lodash_1 = require("lodash");
const get_as_uri_1 = require("../utils/get-as-uri");
const get_as_path_string_1 = require("../utils/get-as-path-string");
const misc_1 = require("../utils/misc");
class Parser {
    async finalConfig(config, resource) {
        if (!config.extends) {
            return config;
        }
        const configIncludes = new Set();
        let configPath = get_as_path_string_1.getAsPathString(get_as_uri_1.getAsUri(resource));
        configIncludes.add(path.normalize(configPath));
        let finalConfigJSON = lodash_1.merge({}, config);
        while (finalConfigJSON.extends) {
            const lastPath = configPath;
            const configDir = path.dirname(configPath);
            configPath = path.resolve(configDir, finalConfigJSON.extends);
            if (configIncludes.has(configPath)) {
                const errorEvent = {
                    error: new Error(`Circular reference found in file ${lastPath}`),
                    resource
                };
                await this.sonarwhal.emitAsync(`parse::${this.name}::error::circular`, errorEvent);
                return null;
            }
            delete finalConfigJSON.extends;
            try {
                const extendedConfig = misc_1.loadJSONFile(configPath);
                console.log(`adding: ${configPath}`);
                configIncludes.add(configPath);
                finalConfigJSON = lodash_1.merge({}, extendedConfig, finalConfigJSON);
            }
            catch (err) {
                const error = {
                    error: err,
                    resource
                };
                await this.sonarwhal.emitAsync(`parse::${this.name}::error::extends`, error);
                return null;
            }
        }
        return finalConfigJSON;
    }
    constructor(sonarwhal, parseEventType) {
        this.sonarwhal = sonarwhal;
        this.name = parseEventType;
    }
}
exports.Parser = Parser;
